==> webgui_7.8.21.orig.tar.gz: WebGUI/lib/WebGUI/i18n/German/Asset_StockData.pm <==
package WebGUI::i18n::German::Asset_StockData;
use utf8;
our $I18N = {
  '% Change' => {
    'lastUpdated' => '1252338663',
    'message' => '% Änderung'
  },
  '52 Wk High' => {
    'lastUpdated' => '1252338731',
    'message' => '52 Wochenhoch'
  },
  '52 Wk Low' => {
    'lastUpdated' => '1252338740',
    'message' => '52 Wochentief'
  },
  'Change' => {
    'lastUpdated' => '1252338746',
    'message' => 'Änderung'
  },
  'Close' => {
    'lastUpdated' => '1252338752',
    'message' => 'Schluss'
  },
  'Day High' => {
    'lastUpdated' => '1252338758',
    'message' => 'Tageshoch'
  },
  'Day Low' => {
    'lastUpdated' => '1252338764',
    'message' => 'Tagestief'
  },
  'Dividend' => {
    'lastUpdated' => '1252338775',
    'message' => 'Dividende'
  },
  'EPS' => {
    'lastUpdated' => '1252338828',
    'message' => 'E.P.S.'
  },
  'Exchange' => {
    'lastUpdated' => '1252338859',
    'message' => 'Handelsplatz'
  },
  'Last Trade' => {
    'lastUpdated' => '1252339060',
    'message' => 'Letzter Handel'
  },
  'Last Update' => {
    'lastUpdated' => '1252020588',
    'message' => 'Letzte Aktualisierung'
  },
  'Market Cap' => {
    'lastUpdated' => '1252339088',
    'message' => 'Marktkapitalisierung'
  },
  'Open' => {
    'lastUpdated' => '1252020610',
    'message' => 'Offen'
  },
  'Prev Close' => {
    'lastUpdated' => '1252339113',
    'message' => 'Schluss Vortag'
  },
  'Stock Watch' => {
    'lastUpdated' => '1252339153',
    'message' => 'Stock Watch'
  },
  'Volume' => {
    'lastUpdated' => '1252020624',
    'message' => 'Menge'
  },
  'Yield' => {
    'lastUpdated' => '1252339164',
    'message' => 'Yield'
  },
  'add_button_label' => {
    'lastUpdated' => '1157856495',
    'message' => 'Hinzufügen &gt;&gt;<br />'
  },
  'assetName' => {
    'lastUpdated' => '1241126766',
    'message' => 'Börsendaten'
  },
  'defaultStocks' => {
    'lastUpdated' => '1252339245',
    'message' => 'Standardliste des Aktienbestandes wenn der Nutzer keinen gewählt hat. String zeilenweise.'
  },
  'default_stock_description' => {
    'lastUpdated' => '1252339347',
    'message' => 'Geben Sie den Standard-Aktienbestand den Sie Besuchern und Benutzer ohne personalisiertes Depot anzeigen möchten. Eine Aktie pro Zeile.'
  },
  'default_stock_label' => {
    'lastUpdated' => '1252339357',
    'message' => 'Standarddepot'
  },
  'default_stock_label_description' => {
    'lastUpdated' => '1252339394',
    'message' => 'Geben Sie eine Liste mit Standardaktien an. Für mehrere ein Symbol pro Zeile.'
  },
  'delayed 20 minutes' => {
    'lastUpdated' => '1252339405',
    'message' => '20 Minuten verzögert'
  },
  'delete_confirm' => {
    'lastUpdated' => '1252339432',
    'message' => 'Sind Sie sicher, dass Sie %s aus Ihrem Depot löschen möchten?'
  },
  'displayTemplateId' => {
    'lastUpdated' => '1252339476',
    'message' => 'ID des Templates um dem Benutzer Details seines Depots anzuzeigen.'
  },
  'display_template_label' => {
    'lastUpdated' => '1252339484',
    'message' => 'Stock Display Template'
  },
  'display_template_label_description' => {
    'lastUpdated' => '1252339590',
    'message' => 'Wählen Sie ein Template aus der Liste zur Anzeige individueller Depots. Stock List Display Templates benutzen Templates des Namensraumes "StockList/Display".'
  },
  'editUrl' => {
    'lastUpdated' => '1252339614',
    'message' => 'URL zur Seite auf der Benutzer Ihr Depot bearbeiten können.'
  },
  'edit_title' => {
    'lastUpdated' => '1252339631',
    'message' => 'Aktienliste bearbeiten'
  },
  'extrasFolder' => {
    'lastUpdated' => '1252339685',
    'message' => 'URL zum Extras-Verzeichnis mit den CSS-Dateien und Bildern dieser Börsendaten-Anwendung.'
  },
  'failover' => {
    'lastUpdated' => '1252339734',
    'message' => 'Eine Bedingung die anzeigt, ob failover für dieses Börsendaten-Asset gesetzt ist.'
  },
  'failover_description' => {
    'lastUpdated' => '1252339885',
    'message' => 'Ist diese Option auf "ja" werden alle verfügbaren Kursquellen durchsucht (beginnend mit der Primärquelle). Wenn auf "nein" wird nur die Primärquelle durchsucht. Die Anzahl verfügbarer Aktien wird vermindert, die Geschwindigkeit der Kursabfrage aber stark erhöht.'
  },
  'failover_label' => {
    'lastUpdated' => '1252339897',
    'message' => 'Mehrere Quellen nutzen'
  },
  'failover_label_description' => {
    'lastUpdated' => '1252340029',
    'message' => 'Bei "ja" werden alle verfügbaren Internetquellen nach jeder Aktie durchsucht. "Nein" beschränkt die Suche auf die Primärquelle. Dies beschleunigt die Suchegeschwindigkeit stark, begrenzt aber die zur Verfügung stehende Zahl auf die Aktien von einer Quelle.'
  },
  'finish_button_label' => {
    'lastUpdated' => '1252340035',
    'message' => 'Fertig'
  },
  'help_stock_list_display_template' => {
    'lastUpdated' => '1252343353',
    'message' => 'Stock List Display Template Variables'
  },
  'help_stock_list_template' => {
    'lastUpdated' => '1252343346',
    'message' => 'Stock List Template Variables'
  },
  'isVisitor' => {
    'lastUpdated' => '1253865462',
    'message' => 'Ist der aktuelle Nutzer Besucher? Liefert "wahr" wenn sich der Benutzer gegenüber dem System nicht authentifiziert hat.'
  },
  'lastUpdate.default' => {
    'lastUpdated' => '1252343334',
    'message' => 'Standard-Datums- und Zeitformat an dem Datum und Zeit der Kurse durch die Quellen aktualisiert wurden.'
  },
  'lastUpdate.intl' => {
    'lastUpdated' => '1252343281',
    'message' => 'internationalisiertes Datums- und Zeitformat für Datum und Zeit an der die Kurse zuletzt aktualisiert wurden.'
  },
  'lastUpdate.us' => {
    'lastUpdated' => '1252343239',
    'message' => 'US-Datums- und Zeit-Format für das Detum und die Zeit an der die Kurse von den Quellen zuletzt aktualisiert wurden.'
  },
  'no_symbol' => {
    'lastUpdated' => '1252340760',
    'message' => 'Symbol %s kann in keiner Suchquelle aus der Liste der vorhandenen gefunden werden.'
  },
  'no_symbol_error' => {
    'lastUpdated' => '1252340796',
    'message' => '"Sie haben kein Aktiensymbol eingegeben, das Ihrem Depot hinzugefügt werden soll"'
  },
  'source' => {
    'lastUpdated' => '1252340826',
    'message' => 'Internetquelle die als Quelle für Ihre Aktieninformationen dient'
  },
  'stock data asset template variables title' => {
    'lastUpdated' => '1241126805',
    'message' => 'Börsendaten Asset Template Variablen'
  },
  'stock.display.url' => {
    'lastUpdated' => '1252343178',
    'message' => 'HauptURL zur Seite die die Details für jede Aktie anzeigt. Ein Aktiensymbol muss am Ende dieses URLs angefügt werden.'
  },
  'stock_source' => {
    'lastUpdated' => '1252343128',
    'message' => 'Primärquelle'
  },
  'stock_source_description' => {
    'lastUpdated' => '1252343119',
    'message' => 'Wählen sie die Primärquelle zur Abfrage von Aktiendaten. Dies ist die erste Internetadresse an der die Anwendung sucht. Wenn Sie die Quelle mit den meisten Aktien Ihrer Nutzer auswählen erhöht das die Performanz der Aktienliste stark.'
  },
  'stocks.ask' => {
    'lastUpdated' => '1252342978',
    'message' => 'Angebot'
  },
  'stocks.avg_vol' => {
    'lastUpdated' => '1252342918',
    'message' => 'Durchschnittliches Tagesvolumen'
  },
  'stocks.bid' => {
    'lastUpdated' => '1252342883',
    'message' => 'Gebot'
  },
  'stocks.cap' => {
    'lastUpdated' => '1252342866',
    'message' => 'Marktkapitalisierung'
  },
  'stocks.close' => {
    'lastUpdated' => '1252342847',
    'message' => 'Letzter Schluss'
  },
  'stocks.date' => {
    'lastUpdated' => '1252342834',
    'message' => 'Letztes Handelsdatum (Format MM/DD/YY)'
  },
  'stocks.day_range' => {
    'lastUpdated' => '1252342798',
    'message' => 'Day\'s Range'
  },
  'stocks.div' => {
    'lastUpdated' => '1252342792',
    'message' => 'Dividend per Share '
  },
  'stocks.div_date' => {
    'lastUpdated' => '1252342777',
    'message' => 'Dividend Pay Date'
  },
  'stocks.div_yield' => {
    'lastUpdated' => '1252342783',
    'message' => 'Dividend Yield '
  },
  'stocks.eps' => {
    'lastUpdated' => '1252342767',
    'message' => 'Earnings per Share'
  },
  'stocks.errormsg' => {
    'lastUpdated' => '1252342743',
    'message' => 'Wenn success false ist, kann dieses Feld den Grund enthalten.'
  },
  'stocks.ex_div' => {
    'lastUpdated' => '1252342707',
    'message' => 'Ex-Dividend Date'
  },
  'stocks.exchange' => {
    'lastUpdated' => '1252342692',
    'message' => 'Der Handelsplatz von dem diese Information erhalten wurde.'
  },
  'stocks.high' => {
    'lastUpdated' => '1252342600',
    'message' => 'Tageshoch'
  },
  'stocks.last' => {
    'lastUpdated' => '1252342663',
    'message' => 'Letzter Kurs'
  },
  'stocks.loop' => {
    'lastUpdated' => '1252342638',
    'message' => 'Schleife die alle Standard oder personalisierten Depotwerte liefert'
  },
  'stocks.low' => {
    'lastUpdated' => '1252342592',
    'message' => 'Tagestief'
  },
  'stocks.method' => {
    'lastUpdated' => '1252342584',
    'message' => 'Das Modul das diese Information gefunden hat.'
  },
  'stocks.name' => {
    'lastUpdated' => '1252342544',
    'message' => 'Gesellschaft oder Fondsname'
  },
  'stocks.nav' => {
    'lastUpdated' => '1252342482',
    'message' => 'Nettoassetwert'
  },
  'stocks.net' => {
    'lastUpdated' => '1252342470',
    'message' => 'Nettoänderung'
  },
  'stocks.net.icon' => {
    'lastUpdated' => '1252342463',
    'message' => 'Icon zur Nettoveränderung (up, down, even)'
  },
  'stocks.net.isDown' => {
    'lastUpdated' => '1252342442',
    'message' => 'Nettoveränderung ist negativ'
  },
  'stocks.net.isUp' => {
    'lastUpdated' => '1252342431',
    'message' => 'Nettoveränderung ist positiv'
  },
  'stocks.net.noChange' => {
    'lastUpdated' => '1252342418',
    'message' => 'Nettoveränderung ist Null'
  },
  'stocks.open' => {
    'lastUpdated' => '1252342401',
    'message' => 'Kurseröffnung'
  },
  'stocks.p_change' => {
    'lastUpdated' => '1252342380',
    'message' => 'Prozentuale Änderung zum Schlusskurs des Vortages'
  },
  'stocks.pe' => {
    'lastUpdated' => '1252342340',
    'message' => 'P/E Ratio'
  },
  'stocks.success' => {
    'lastUpdated' => '1252342306',
    'message' => 'Lieferte die Aktien erfolgreich Informationen (wahr/falsch)?'
  },
  'stocks.symbol' => {
    'lastUpdated' => '1252342271',
    'message' => 'Aktiensymbol'
  },
  'stocks.time' => {
    'lastUpdated' => '1252342265',
    'message' => 'Letzte Handelszeit'
  },
  'stocks.volume' => {
    'lastUpdated' => '1252342249',
    'message' => 'Tagesvolumen'
  },
  'stocks.volume.millions' => {
    'lastUpdated' => '1252342241',
    'message' => 'Tagesvolumen in Millionen'
  },
  'stocks.year_high' => {
    'lastUpdated' => '1252342217',
    'message' => '52-Wochen-Hoch'
  },
  'stocks.year_low' => {
    'lastUpdated' => '1252342226',
    'message' => '52-Wochen-Tief'
  },
  'stocks.year_range' => {
    'lastUpdated' => '1252342184',
    'message' => '52-Wochen-Bereich'
  },
  'stocks.yield' => {
    'lastUpdated' => '1252342142',
    'message' => 'Rendite (gewöhnlich 30 Tagesdurchschnitt)'
  },
  'symbol_edit_label' => {
    'lastUpdated' => '1252342025',
    'message' => 'Aktiensymbol hinzufügen/bearbeiten'
  },
  'symbol_exists' => {
    'lastUpdated' => '1252341102',
    'message' => 'Symbol %s ist bereits in Ihrem Depot.'
  },
  'symbol_header' => {
    'lastUpdated' => '1252341085',
    'message' => 'Liste Aktiensymbole'
  },
  'symbol_label' => {
    'lastUpdated' => '1252341070',
    'message' => 'Aktiensymbol'
  },
  'symbol_label_description' => {
    'lastUpdated' => '1252341060',
    'message' => 'Geben Sie ein gültiges Aktiensymbol ein. Wenn Ihr Symbol nicht gefunden wird, kontaktieren Sie den Administrator. Es ist wahrscheinlich, dass Ihre Site die Aktien auf einen bestimmten Markt (US, Europa, ..) beschränkt.'
  },
  'templateId' => {
    'lastUpdated' => '1252340981',
    'message' => 'ID des Templates zur Anzeige der Hauptseite dieses Assets'
  },
  'template_label' => {
    'lastUpdated' => '1252340953',
    'message' => 'Depot-Template'
  },
  'template_label_description' => {
    'lastUpdated' => '1252340943',
    'message' => 'Wählen Sie aus der Liste ein Template zur Anzeige ihres Depots aus. Jedes Depot kann nur Templates aus dem Namensraum "StockList" verwenden.'
  }
}
;

1;

==> webgui_7.10.28.orig.tar.gz: WebGUI/lib/WebGUI/i18n/German/Asset_StockData.pm <==
package WebGUI::i18n::German::Asset_StockData;
use utf8;
our $I18N = {
  '% Change' => {
    'lastUpdated' => '1252338663',
    'message' => '% Änderung'
  },
  '52 Wk High' => {
    'lastUpdated' => '1252338731',
    'message' => '52 Wochenhoch'
  },
  '52 Wk Low' => {
    'lastUpdated' => '1252338740',
    'message' => '52 Wochentief'
  },
  'Change' => {
    'lastUpdated' => '1252338746',
    'message' => 'Änderung'
  },
  'Close' => {
    'lastUpdated' => '1252338752',
    'message' => 'Schluss'
  },
  'Day High' => {
    'lastUpdated' => '1252338758',
    'message' => 'Tageshoch'
  },
  'Day Low' => {
    'lastUpdated' => '1252338764',
    'message' => 'Tagestief'
  },
  'Dividend' => {
    'lastUpdated' => '1252338775',
    'message' => 'Dividende'
  },
  'EPS' => {
    'lastUpdated' => '1252338828',
    'message' => 'E.P.S.'
  },
  'Exchange' => {
    'lastUpdated' => '1252338859',
    'message' => 'Handelsplatz'
  },
  'Last Trade' => {
    'lastUpdated' => '1252339060',
    'message' => 'Letzter Handel'
  },
  'Last Update' => {
    'lastUpdated' => '1252020588',
    'message' => 'Letzte Aktualisierung'
  },
  'Market Cap' => {
    'lastUpdated' => '1252339088',
    'message' => 'Marktkapitalisierung'
  },
  'Open' => {
    'lastUpdated' => '1252020610',
    'message' => 'Offen'
  },
  'Prev Close' => {
    'lastUpdated' => '1252339113',
    'message' => 'Schluss Vortag'
  },
  'Stock Watch' => {
    'lastUpdated' => '1252339153',
    'message' => 'Stock Watch'
  },
  'Volume' => {
    'lastUpdated' => '1252020624',
    'message' => 'Menge'
  },
  'Yield' => {
    'lastUpdated' => '1252339164',
    'message' => 'Yield'
  },
  'add_button_label' => {
    'lastUpdated' => '1157856495',
    'message' => 'Hinzufügen &gt;&gt;<br />'
  },
  'assetName' => {
    'lastUpdated' => '1241126766',
    'message' => 'Börsendaten'
  },
  'cache timeout help' => {
    'lastUpdated' => '1301988868',
    'message' => 'Wie lange sollen die abgerufenen Aktiensymbole intern gecached werden? Hinweis: Das Standardtemplate nutzt Javascript um die Abrufe clientseitig durchzuführen.'
  },
  'defaultStocks' => {
    'lastUpdated' => '1252339245',
    'message' => 'Standardliste des Aktienbestandes wenn der Nutzer keinen gewählt hat. String zeilenweise.'
  },
  'default_stock_description' => {
    'lastUpdated' => '1252339347',
    'message' => 'Geben Sie den Standard-Aktienbestand den Sie Besuchern und Benutzer ohne personalisiertes Depot anzeigen möchten. Eine Aktie pro Zeile.'
  },
  'default_stock_label' => {
    'lastUpdated' => '1252339357',
    'message' => 'Standarddepot'
  },
  'default_stock_label_description' => {
    'lastUpdated' => '1252339394',
    'message' => 'Geben Sie eine Liste mit Standardaktien an. Für mehrere ein Symbol pro Zeile.'
  },
  'delayed 20 minutes' => {
    'lastUpdated' => '1252339405',
    'message' => '20 Minuten verzögert'
  },
  'delete_confirm' => {
    'lastUpdated' => '1252339432',
    'message' => 'Sind Sie sicher, dass Sie %s aus Ihrem Depot löschen möchten?'
  },
  'displayTemplateId' => {
    'lastUpdated' => '1252339476',
    'message' => 'ID des Templates um dem Benutzer Details seines Depots anzuzeigen.'
  },
  'display_template_label' => {
    'lastUpdated' => '1252339484',
    'message' => 'Stock Display Template'
  },
  'display_template_label_description' => {
    'lastUpdated' => '1252339590',
    'message' => 'Wählen Sie ein Template aus der Liste zur Anzeige individueller Depots. Stock List Display Templates benutzen Templates des Namensraumes "StockList/Display".'
  },
  'editUrl' => {
    'lastUpdated' => '1252339614',
    'message' => 'URL zur Seite auf der Benutzer Ihr Depot bearbeiten können.'
  },
  'edit_title' => {
    'lastUpdated' => '1252339631',
    'message' => 'Aktienliste bearbeiten'
  },
  'extrasFolder' => {
    'lastUpdated' => '1252339685',
    'message' => 'URL zum Extras-Verzeichnis mit den CSS-Dateien und Bildern dieser Börsendaten-Anwendung.'
  },
  'failover' => {
    'lastUpdated' => '1252339734',
    'message' => 'Eine Bedingung die anzeigt, ob failover für dieses Börsendaten-Asset gesetzt ist.'
  },
  'failover_description' => {
    'lastUpdated' => '1252339885',
    'message' => 'Ist diese Option auf "ja" werden alle verfügbaren Kursquellen durchsucht (beginnend mit der Primärquelle). Wenn auf "nein" wird nur die Primärquelle durchsucht. Die Anzahl verfügbarer Aktien wird vermindert, die Geschwindigkeit der Kursabfrage aber stark erhöht.'
  },
  'failover_label' => {
    'lastUpdated' => '1252339897',
    'message' => 'Mehrere Quellen nutzen'
  },
  'failover_label_description' => {
    'lastUpdated' => '1252340029',
    'message' => 'Bei "ja" werden alle verfügbaren Internetquellen nach jeder Aktie durchsucht. "Nein" beschränkt die Suche auf die Primärquelle. Dies beschleunigt die Suchegeschwindigkeit stark, begrenzt aber die zur Verfügung stehende Zahl auf die Aktien von einer Quelle.'
  },
  'finish_button_label' => {
    'lastUpdated' => '1252340035',
    'message' => 'Fertig'
  },
  'help_stock_list_display_template' => {
    'lastUpdated' => '1252343353',
    'message' => 'Stock List Display Template Variables'
  },
  'help_stock_list_template' => {
    'lastUpdated' => '1252343346',
    'message' => 'Stock List Template Variables'
  },
  'isVisitor' => {
    'lastUpdated' => '1253865462',
    'message' => 'Ist der aktuelle Nutzer Besucher? Liefert "wahr" wenn sich der Benutzer gegenüber dem System nicht authentifiziert hat.'
  },
  'lastUpdate.default' => {
    'lastUpdated' => '1252343334',
    'message' => 'Standard-Datums- und Zeitformat an dem Datum und Zeit der Kurse durch die Quellen aktualisiert wurden.'
  },
  'lastUpdate.intl' => {
    'lastUpdated' => '1252343281',
    'message' => 'internationalisiertes Datums- und Zeitformat für Datum und Zeit an der die Kurse zuletzt aktualisiert wurden.'
  },
  'lastUpdate.us' => {
    'lastUpdated' => '1252343239',
    'message' => 'US-Datums- und Zeit-Format für das Detum und die Zeit an der die Kurse von den Quellen zuletzt aktualisiert wurden.'
  },
  'no_symbol' => {
    'lastUpdated' => '1252340760',
    'message' => 'Symbol %s kann in keiner Suchquelle aus der Liste der vorhandenen gefunden werden.'
  },
  'no_symbol_error' => {
    'lastUpdated' => '1252340796',
    'message' => '"Sie haben kein Aktiensymbol eingegeben, das Ihrem Depot hinzugefügt werden soll"'
  },
  'source' => {
    'lastUpdated' => '1252340826',
    'message' => 'Internetquelle die als Quelle für Ihre Aktieninformationen dient'
  },
  'stock data asset template variables title' => {
    'lastUpdated' => '1241126805',
    'message' => 'Börsendaten Asset Template Variablen'
  },
  'stock.display.url' => {
    'lastUpdated' => '1252343178',
    'message' => 'HauptURL zur Seite die die Details für jede Aktie anzeigt. Ein Aktiensymbol muss am Ende dieses URLs angefügt werden.'
  },
  'stock_source' => {
    'lastUpdated' => '1252343128',
    'message' => 'Primärquelle'
  },
  'stock_source_description' => {
    'lastUpdated' => '1252343119',
    'message' => 'Wählen sie die Primärquelle zur Abfrage von Aktiendaten. Dies ist die erste Internetadresse an der die Anwendung sucht. Wenn Sie die Quelle mit den meisten Aktien Ihrer Nutzer auswählen erhöht das die Performanz der Aktienliste stark.'
  },
  'stocks.ask' => {
    'lastUpdated' => '1252342978',
    'message' => 'Angebot'
  },
  'stocks.avg_vol' => {
    'lastUpdated' => '1252342918',
    'message' => 'Durchschnittliches Tagesvolumen'
  },
  'stocks.bid' => {
    'lastUpdated' => '1252342883',
    'message' => 'Gebot'
  },
  'stocks.cap' => {
    'lastUpdated' => '1252342866',
    'message' => 'Marktkapitalisierung'
  },
  'stocks.close' => {
    'lastUpdated' => '1252342847',
    'message' => 'Letzter Schluss'
  },
  'stocks.date' => {
    'lastUpdated' => '1252342834',
    'message' => 'Letztes Handelsdatum (Format MM/DD/YY)'
  },
  'stocks.day_range' => {
    'lastUpdated' => '1252342798',
    'message' => 'Day\'s Range'
  },
  'stocks.div' => {
    'lastUpdated' => '1252342792',
    'message' => 'Dividend per Share '
  },
  'stocks.div_date' => {
    'lastUpdated' => '1252342777',
    'message' => 'Dividend Pay Date'
  },
  'stocks.div_yield' => {
    'lastUpdated' => '1252342783',
    'message' => 'Dividend Yield '
  },
  'stocks.eps' => {
    'lastUpdated' => '1252342767',
    'message' => 'Earnings per Share'
  },
  'stocks.errormsg' => {
    'lastUpdated' => '1252342743',
    'message' => 'Wenn success false ist, kann dieses Feld den Grund enthalten.'
  },
  'stocks.ex_div' => {
    'lastUpdated' => '1252342707',
    'message' => 'Ex-Dividend Date'
  },
  'stocks.exchange' => {
    'lastUpdated' => '1252342692',
    'message' => 'Der Handelsplatz von dem diese Information erhalten wurde.'
  },
  'stocks.high' => {
    'lastUpdated' => '1252342600',
    'message' => 'Tageshoch'
  },
  'stocks.last' => {
    'lastUpdated' => '1252342663',
    'message' => 'Letzter Kurs'
  },
  'stocks.loop' => {
    'lastUpdated' => '1252342638',
    'message' => 'Schleife die alle Standard oder personalisierten Depotwerte liefert'
  },
  'stocks.low' => {
    'lastUpdated' => '1252342592',
    'message' => 'Tagestief'
  },
  'stocks.method' => {
    'lastUpdated' => '1252342584',
    'message' => 'Das Modul das diese Information gefunden hat.'
  },
  'stocks.name' => {
    'lastUpdated' => '1252342544',
    'message' => 'Gesellschaft oder Fondsname'
  },
  'stocks.nav' => {
    'lastUpdated' => '1252342482',
    'message' => 'Nettoassetwert'
  },
  'stocks.net' => {
    'lastUpdated' => '1252342470',
    'message' => 'Nettoänderung'
  },
  'stocks.net.icon' => {
    'lastUpdated' => '1252342463',
    'message' => 'Icon zur Nettoveränderung (up, down, even)'
  },
  'stocks.net.isDown' => {
    'lastUpdated' => '1252342442',
    'message' => 'Nettoveränderung ist negativ'
  },
  'stocks.net.isUp' => {
    'lastUpdated' => '1252342431',
    'message' => 'Nettoveränderung ist positiv'
  },
  'stocks.net.noChange' => {
    'lastUpdated' => '1252342418',
    'message' => 'Nettoveränderung ist Null'
  },
  'stocks.open' => {
    'lastUpdated' => '1252342401',
    'message' => 'Kurseröffnung'
  },
  'stocks.p_change' => {
    'lastUpdated' => '1252342380',
    'message' => 'Prozentuale Änderung zum Schlusskurs des Vortages'
  },
  'stocks.pe' => {
    'lastUpdated' => '1252342340',
    'message' => 'P/E Ratio'
  },
  'stocks.success' => {
    'lastUpdated' => '1252342306',
    'message' => 'Lieferte die Aktien erfolgreich Informationen (wahr/falsch)?'
  },
  'stocks.symbol' => {
    'lastUpdated' => '1252342271',
    'message' => 'Aktiensymbol'
  },
  'stocks.time' => {
    'lastUpdated' => '1252342265',
    'message' => 'Letzte Handelszeit'
  },
  'stocks.volume' => {
    'lastUpdated' => '1252342249',
    'message' => 'Tagesvolumen'
  },
  'stocks.volume.millions' => {
    'lastUpdated' => '1252342241',
    'message' => 'Tagesvolumen in Millionen'
  },
  'stocks.year_high' => {
    'lastUpdated' => '1252342217',
    'message' => '52-Wochen-Hoch'
  },
  'stocks.year_low' => {
    'lastUpdated' => '1252342226',
    'message' => '52-Wochen-Tief'
  },
  'stocks.year_range' => {
    'lastUpdated' => '1252342184',
    'message' => '52-Wochen-Bereich'
  },
  'stocks.yield' => {
    'lastUpdated' => '1252342142',
    'message' => 'Rendite (gewöhnlich 30 Tagesdurchschnitt)'
  },
  'symbol_edit_label' => {
    'lastUpdated' => '1252342025',
    'message' => 'Aktiensymbol hinzufügen/bearbeiten'
  },
  'symbol_exists' => {
    'lastUpdated' => '1252341102',
    'message' => 'Symbol %s ist bereits in Ihrem Depot.'
  },
  'symbol_header' => {
    'lastUpdated' => '1252341085',
    'message' => 'Liste Aktiensymbole'
  },
  'symbol_label' => {
    'lastUpdated' => '1252341070',
    'message' => 'Aktiensymbol'
  },
  'symbol_label_description' => {
    'lastUpdated' => '1252341060',
    'message' => 'Geben Sie ein gültiges Aktiensymbol ein. Wenn Ihr Symbol nicht gefunden wird, kontaktieren Sie den Administrator. Es ist wahrscheinlich, dass Ihre Site die Aktien auf einen bestimmten Markt (US, Europa, ..) beschränkt.'
  },
  'templateId' => {
    'lastUpdated' => '1252340981',
    'message' => 'ID des Templates zur Anzeige der Hauptseite dieses Assets'
  },
  'template_label' => {
    'lastUpdated' => '1252340953',
    'message' => 'Depot-Template'
  },
  'template_label_description' => {
    'lastUpdated' => '1252340943',
    'message' => 'Wählen Sie aus der Liste ein Template zur Anzeige ihres Depots aus. Jedes Depot kann nur Templates aus dem Namensraum "StockList" verwenden.'
  }
}
;

1;
